#!perl -w
use strict;
use PureMessage::Version qw($PREFIX);
die "PureMessage is not properly installed"
    unless $PREFIX && $PREFIX !~ /^%%/;

use lib "./support";
use ActiveState::Install qw(install installed);
use ActiveState::Prompt qw(prompt yes);
use ActiveState::Unix::Crontab qw(cron_cmds cron_add cron_list cron_install
				  cron_parse cron_format
				 );

# Protect against failing to install over top of the old Sophos Integration
# Kit (which recommended setting up a symlink here). If it points to a
# root-owned location, it would cause the install() to fail, so unlink it.
# Don't croak if that fails, since install() will work if it's a directory.
unless (installed(etc => "$PREFIX/etc", pkg => "PureMessage-Sophos-Data")) {
    unlink "$PREFIX/etc/data/sophos";
}

install(
    files => {
	etc => "$PREFIX/etc",
    },
    pkg => "PureMessage-Sophos-Data",
    ver => "2025.5.2.602000",
    etc => "$PREFIX/etc",
);

my $inc = '';
if (@INC) {
   $inc .= " -I$_" foreach (@INC);
}
my $cmd = "$^X $inc $PREFIX/bin/pmx-sophos-data update";
system($cmd) == 0 or die "can't run '$cmd': $?";

# Attempt to set up a scheduled task for PureMessage 5.x; if this
# fails, fall back to the cron method for PureMessage 4.x.
eval {
    require PureMessage::Scheduler::CronConvert;
    cron_install(PureMessage::Scheduler::CronConvert::jobs2events(job_spec => {
	id => 'pmx-sophos-data-update',
	re => qr/verify --upgrade PureMessage-Sophos-Data/,
    }))
	if -e "$PREFIX/etc/.v4_upgrade";
};

exit unless $@;

# Not a 5.x install: use cronjobs.
eval {
    if (grep /PureMessage-Sophos-Data/, cron_cmds()) {
	print "Cron updates for PureMessage-Sophos-Data already installed.\n";
	update_cronjob();
    }
    elsif (-t) {
	print <<EOT;
    Sophos regularly publishes updates for the virus signature files 
    used by PureMessage.  The installer can create a cron job that will
    check for and, when available, install updates every hour.

EOT

	if (yes("Install cron job to update virus signatures?", 1)) {
	    add_cronjob(1);
	    print "Done.\n\n";
	}
	else {
	    add_cronjob(0);
	    print "Ok.\n\n";
	}
    }
    else {
	add_cronjob(0);
    }
};
warn $@ if $@;

sub add_cronjob {
    my $enabled = shift;
    cron_add(
	cmd => qq($PREFIX/bin/ppm verify --upgrade PureMessage-Sophos-Data 2>&1 | grep -v "is up to date."),
	comment => "update PureMessage virus signatures hourly",
	min => int(rand(60)),
	enabled => $enabled,
    );
}

sub update_cronjob {
    my @cronjobs = cron_list();
    for my $j (@cronjobs) {
	my %job = cron_parse($j);
	if ($job{cmd} =~ /PureMessage-Sophos-Data/ && exists $job{hour}) {
	    delete $job{hour};
	    $j = cron_format(%job);
	    cron_install(@cronjobs);
	    return;
	}
    }
}

1;
